#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 scientific
version:              0.3.6.2
visibility:           public
id:                   scientific-0.3.6.2-ErrVUcpZzeLEYjP4jqSF4S
key:                  scientific-0.3.6.2-ErrVUcpZzeLEYjP4jqSF4S
license:              BSD-3-Clause
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk
homepage:             https://github.com/basvandijk/scientific
synopsis:             Numbers represented using scientific notation
description:
    "Data.Scientific" provides the number type '\''Scientific'\''. Scientific numbers are
    arbitrary precision and space efficient. They are represented using
    <http://en.wikipedia.org/wiki/Scientific_notation scientific notation>.
    The implementation uses a coefficient @c :: '\''Integer'\''@ and a base-10 exponent
    @e :: '\''Int'\''@. A scientific number corresponds to the
    '\''Fractional'\'' number: @'\''fromInteger'\'' c * 10 '\''^^'\'' e@.

    Note that since we'\''re using an '\''Int'\'' to represent the exponent these numbers
    aren'\''t truly arbitrary precision. I intend to change the type of the exponent
    to '\''Integer'\'' in a future release.

    The main application of '\''Scientific'\'' is to be used as the target of parsing
    arbitrary precision numbers coming from an untrusted source. The advantages
    over using '\''Rational'\'' for this are that:

    * A '\''Scientific'\'' is more efficient to construct. Rational numbers need to be
    constructed using '\''%'\'' which has to compute the '\''gcd'\'' of the '\''numerator'\'' and
    '\''denominator'\''.

    * '\''Scientific'\'' is safe against numbers with huge exponents. For example:
    @1e1000000000 :: '\''Rational'\''@ will fill up all space and crash your
    program. Scientific works as expected:

    >>> read "1e1000000000" :: Scientific
    1.0e1000000000

    * Also, the space usage of converting scientific numbers with huge exponents to
    @'\''Integral'\''s@ (like: '\''Int'\'') or @'\''RealFloat'\''s@ (like: '\''Double'\'' or '\''Float'\'')
    will always be bounded by the target type.

category:             Data
abi:                  7de6f20010a9ac8c98b1e903aaabde79
exposed:              True
exposed-modules:
    Data.ByteString.Builder.Scientific Data.Scientific
    Data.Text.Lazy.Builder.Scientific

hidden-modules:       GHC.Integer.Compat Utils
import-dirs:          /usr/lib/ghc-8.10.4/site-local/scientific-0.3.6.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/scientific-0.3.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/scientific-0.3.6.2
hs-libraries:         HSscientific-0.3.6.2-ErrVUcpZzeLEYjP4jqSF4S
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.12.0
    containers-0.6.2.1 deepseq-1.4.4.0
    hashable-1.3.1.0-4EsGp1K7uOu2cACWuCidz3 integer-gmp-1.0.3.0
    integer-logarithms-1.0.3.1-8l1ymRbE3rBG8A7FKIRWkt
    primitive-0.7.1.0-8SQOE2avl1z6s0yo5beOHC text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-scientific/html/scientific.haddock
haddock-html:         /usr/share/doc/haskell-scientific/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

